@@ -19,8 +19,6 @@
 #include <Zend/zend_interfaces.h>
 #include <Zend/zend_exceptions.h>
 #include <Zend/zend_operators.h>
-#include <ext/standard/php_var.h>
-#include <zend_smart_str.h>
 
 #ifdef HAVE_CONFIG_H
 #include "config.h"
@@ -401,62 +399,6 @@ static PHP_METHOD(MongoDB_BSON_PackedArray, __set_state)
 	php_phongo_packedarray_init_from_hash(intern, props);
 }
 
-static PHP_METHOD(MongoDB_BSON_PackedArray, serialize)
-{
-	php_phongo_packedarray_t* intern;
-	zval                      retval;
-	php_serialize_data_t      var_hash;
-	smart_str                 buf = { 0 };
-	zend_string*              str;
-
-	intern = Z_PACKEDARRAY_OBJ_P(getThis());
-
-	PHONGO_PARSE_PARAMETERS_NONE();
-
-	array_init_size(&retval, 1);
-	str = php_base64_encode(bson_get_data(intern->bson), intern->bson->len);
-	ADD_ASSOC_STR(&retval, "data", str);
-
-	PHP_VAR_SERIALIZE_INIT(var_hash);
-	php_var_serialize(&buf, &retval, &var_hash);
-	smart_str_0(&buf);
-	PHP_VAR_SERIALIZE_DESTROY(var_hash);
-
-	PHONGO_RETVAL_SMART_STR(buf);
-
-	zend_string_free(str);
-	smart_str_free(&buf);
-	zval_ptr_dtor(&retval);
-}
-
-static PHP_METHOD(MongoDB_BSON_PackedArray, unserialize)
-{
-	php_phongo_packedarray_t* intern;
-	char*                     serialized;
-	size_t                    serialized_len;
-	zval                      props;
-	php_unserialize_data_t    var_hash;
-
-	intern = Z_PACKEDARRAY_OBJ_P(getThis());
-
-	PHONGO_PARSE_PARAMETERS_START(1, 1)
-	Z_PARAM_STRING(serialized, serialized_len)
-	PHONGO_PARSE_PARAMETERS_END();
-
-	PHP_VAR_UNSERIALIZE_INIT(var_hash);
-	if (!php_var_unserialize(&props, (const unsigned char**) &serialized, (unsigned char*) serialized + serialized_len, &var_hash)) {
-		zval_ptr_dtor(&props);
-		phongo_throw_exception(PHONGO_ERROR_UNEXPECTED_VALUE, "%s unserialization failed", ZSTR_VAL(php_phongo_packedarray_ce->name));
-
-		PHP_VAR_UNSERIALIZE_DESTROY(var_hash);
-		return;
-	}
-	PHP_VAR_UNSERIALIZE_DESTROY(var_hash);
-
-	php_phongo_packedarray_init_from_hash(intern, HASH_OF(&props));
-	zval_ptr_dtor(&props);
-}
-
 static PHP_METHOD(MongoDB_BSON_PackedArray, __serialize)
 {
 	PHONGO_PARSE_PARAMETERS_NONE();
@@ -624,7 +566,7 @@ void php_phongo_packedarray_unset_dimension(zend_object* object, zval* offset)
 
 void php_phongo_packedarray_init_ce(INIT_FUNC_ARGS)
 {
-	php_phongo_packedarray_ce                = register_class_MongoDB_BSON_PackedArray(zend_ce_aggregate, zend_ce_serializable, zend_ce_arrayaccess, php_phongo_type_ce, zend_ce_stringable);
+	php_phongo_packedarray_ce                = register_class_MongoDB_BSON_PackedArray(zend_ce_aggregate, zend_ce_arrayaccess, php_phongo_type_ce, zend_ce_stringable);
 	php_phongo_packedarray_ce->create_object = php_phongo_packedarray_create_object;
 
 	memcpy(&php_phongo_handler_packedarray, phongo_get_std_object_handlers(), sizeof(zend_object_handlers));
