@@ -280,6 +280,7 @@ static bool php_phongo_bulkwrite_update_apply_options(bson_t* boptions, zval* zo
 	PHONGO_BULKWRITE_APPEND_BOOL("upsert", upsert);
 	PHONGO_BULKWRITE_OPT_ARRAY("arrayFilters");
 	PHONGO_BULKWRITE_OPT_DOCUMENT("collation");
+	PHONGO_BULKWRITE_OPT_DOCUMENT("sort");
 
 	if (!php_phongo_bulkwrite_opt_hint(boptions, zoptions)) {
 		return false;
@@ -381,9 +382,8 @@ static PHP_METHOD(MongoDB_Driver_BulkWrite, insert)
 	php_phongo_bulkwrite_t* intern;
 	zval*                   zdocument;
 	bson_t                  bdocument = BSON_INITIALIZER, boptions = BSON_INITIALIZER;
-	bson_t*                 bson_out   = NULL;
-	int                     bson_flags = PHONGO_BSON_ADD_ID;
-	bson_error_t            error      = { 0 };
+	bson_t*                 bson_out = NULL;
+	bson_error_t            error    = { 0 };
 
 	intern = Z_BULKWRITE_OBJ_P(getThis());
 
@@ -391,14 +391,17 @@ static PHP_METHOD(MongoDB_Driver_BulkWrite, insert)
 	Z_PARAM_ARRAY_OR_OBJECT(zdocument)
 	PHONGO_PARSE_PARAMETERS_END();
 
-	bson_flags |= PHONGO_BSON_RETURN_ID;
-
-	php_phongo_zval_to_bson(zdocument, bson_flags, &bdocument, &bson_out);
+	php_phongo_zval_to_bson(zdocument, (PHONGO_BSON_ADD_ID | PHONGO_BSON_RETURN_ID), &bdocument, &bson_out);
 
 	if (EG(exception)) {
 		goto cleanup;
 	}
 
+	if (!bson_out) {
+		phongo_throw_exception(PHONGO_ERROR_LOGIC, "php_phongo_zval_to_bson() did not return an _id. Please file a bug report.");
+		goto cleanup;
+	}
+
 	if (!mongoc_bulk_operation_insert_with_opts(intern->bulk, &bdocument, &boptions, &error)) {
 		phongo_throw_exception_from_bson_error_t(&error);
 		goto cleanup;
@@ -406,11 +409,6 @@ static PHP_METHOD(MongoDB_Driver_BulkWrite, insert)
 
 	intern->num_ops++;
 
-	if (!bson_out) {
-		phongo_throw_exception(PHONGO_ERROR_LOGIC, "Did not receive result from bulk write. Please file a bug report.");
-		goto cleanup;
-	}
-
 	php_phongo_bulkwrite_extract_id(bson_out, &return_value);
 
 cleanup:
@@ -589,13 +587,13 @@ static zend_object* php_phongo_bulkwrite_create_object(zend_class_entry* class_t
 	return &intern->std;
 }
 
-static HashTable* php_phongo_bulkwrite_get_debug_info(phongo_compat_object_handler_type* object, int* is_temp)
+static HashTable* php_phongo_bulkwrite_get_debug_info(zend_object* object, int* is_temp)
 {
 	zval                    retval = ZVAL_STATIC_INIT;
 	php_phongo_bulkwrite_t* intern = NULL;
 
 	*is_temp = 1;
-	intern   = Z_OBJ_BULKWRITE(PHONGO_COMPAT_GET_OBJ(object));
+	intern   = Z_OBJ_BULKWRITE(object);
 	array_init(&retval);
 
 	if (intern->database) {
@@ -667,7 +665,6 @@ void php_phongo_bulkwrite_init_ce(INIT_FUNC_ARGS)
 {
 	php_phongo_bulkwrite_ce                = register_class_MongoDB_Driver_BulkWrite(zend_ce_countable);
 	php_phongo_bulkwrite_ce->create_object = php_phongo_bulkwrite_create_object;
-	PHONGO_CE_DISABLE_SERIALIZATION(php_phongo_bulkwrite_ce);
 
 	memcpy(&php_phongo_handler_bulkwrite, phongo_get_std_object_handlers(), sizeof(zend_object_handlers));
 	php_phongo_handler_bulkwrite.get_debug_info = php_phongo_bulkwrite_get_debug_info;
