@@ -1,5 +1,5 @@
 /*
- * Copyright 2014 MongoDB, Inc.
+ * Copyright 2009-present MongoDB, Inc.
  *
  * Licensed under the Apache License, Version 2.0 (the "License");
  * you may not use this file except in compliance with the License.
@@ -14,19 +14,16 @@
  * limitations under the License.
  */
 
+#include <bson/bson-prelude.h>
+
 
 #ifndef BSON_CLOCK_H
 #define BSON_CLOCK_H
 
 
-#if !defined(BSON_INSIDE) && !defined(BSON_COMPILATION)
-#error "Only <bson/bson.h> can be included directly."
-#endif
-
-
-#include "bson/bson-compat.h"
-#include "bson/bson-macros.h"
-#include "bson/bson-types.h"
+#include <bson/bson-compat.h>
+#include <bson/bson-macros.h>
+#include <bson/bson-types.h>
 
 
 BSON_BEGIN_DECLS
