@@ -1,5 +1,5 @@
 /*
- * Copyright 2017 MongoDB, Inc.
+ * Copyright 2009-present MongoDB, Inc.
  *
  * Licensed under the Apache License, Version 2.0 (the "License");
  * you may not use this file except in compliance with the License.
@@ -14,15 +14,13 @@
  * limitations under the License.
  */
 
+#include <mongoc/mongoc-prelude.h>
+
 #ifndef MONGOC_CLUSTER_CYRUS_PRIVATE_H
 #define MONGOC_CLUSTER_CYRUS_PRIVATE_H
 
-#if !defined(MONGOC_COMPILATION)
-#error "Only <mongoc/mongoc.h> can be included directly."
-#endif
-
-#include "mongoc/mongoc-config.h"
-#include "mongoc/mongoc-cluster-private.h"
+#include <mongoc/mongoc-config.h>
+#include <mongoc/mongoc-cluster-private.h>
 #include <bson/bson.h>
 
 bool
