@@ -1,5 +1,5 @@
 /*
- * Copyright 2017 MongoDB, Inc.
+ * Copyright 2009-present MongoDB, Inc.
  *
  * Licensed under the Apache License, Version 2.0 (the "License");
  * you may not use this file except in compliance with the License.
@@ -15,15 +15,15 @@
  */
 
 
-#include "mongoc-cmd-private.h"
-#include "mongoc-read-prefs-private.h"
-#include "mongoc-trace-private.h"
-#include "mongoc-client-private.h"
-#include "mongoc-read-concern-private.h"
-#include "mongoc-server-api-private.h"
-#include "mongoc-write-concern-private.h"
+#include <mongoc/mongoc-cmd-private.h>
+#include <mongoc/mongoc-read-prefs-private.h>
+#include <mongoc/mongoc-trace-private.h>
+#include <mongoc/mongoc-client-private.h>
+#include <mongoc/mongoc-read-concern-private.h>
+#include <mongoc/mongoc-server-api-private.h>
+#include <mongoc/mongoc-write-concern-private.h>
 /* For strcasecmp on Windows */
-#include "mongoc-util-private.h"
+#include <mongoc/mongoc-util-private.h>
 
 
 void
@@ -56,6 +56,7 @@ mongoc_cmd_parts_init (mongoc_cmd_parts_t *parts,
    parts->assembled.query_flags = MONGOC_QUERY_NONE;
    parts->assembled.op_msg_is_exhaust = false;
    parts->assembled.payloads_count = 0;
+   memset (parts->assembled.payloads, 0, sizeof parts->assembled.payloads);
    parts->assembled.session = NULL;
    parts->assembled.is_acknowledged = true;
    parts->assembled.is_txn_finish = false;
@@ -325,30 +326,13 @@ static void
 _mongoc_cmd_parts_add_read_prefs (bson_t *query, const mongoc_read_prefs_t *prefs)
 {
    bson_t child;
-   const char *mode_str;
-   const bson_t *tags;
-   int64_t stale;
-   const bson_t *hedge;
-
-   mode_str = _mongoc_read_mode_as_str (mongoc_read_prefs_get_mode (prefs));
-   tags = mongoc_read_prefs_get_tags (prefs);
-   stale = mongoc_read_prefs_get_max_staleness_seconds (prefs);
-   hedge = mongoc_read_prefs_get_hedge (prefs);
 
    bson_append_document_begin (query, "$readPreference", 15, &child);
-   bson_append_utf8 (&child, "mode", 4, mode_str, -1);
-   if (!bson_empty0 (tags)) {
-      bson_append_array (&child, "tags", 4, tags);
-   }
-
-   if (stale != MONGOC_NO_MAX_STALENESS) {
-      bson_append_int64 (&child, "maxStalenessSeconds", 19, stale);
-   }
-
-   if (!bson_empty0 (hedge)) {
-      bson_append_document (&child, "hedge", 5, hedge);
-   }
-
+   mongoc_read_prefs_append_contents_to_bson (
+      prefs,
+      &child,
+      MONGOC_READ_PREFS_CONTENT_FLAG_MODE | MONGOC_READ_PREFS_CONTENT_FLAG_TAGS |
+         MONGOC_READ_PREFS_CONTENT_FLAG_MAX_STALENESS_SECONDS | MONGOC_READ_PREFS_CONTENT_FLAG_HEDGE);
    bson_append_document_end (query, &child);
 }
 
@@ -948,7 +932,7 @@ mongoc_cmd_parts_cleanup (mongoc_cmd_parts_t *parts)
 }
 
 bool
-mongoc_cmd_is_compressible (mongoc_cmd_t *cmd)
+mongoc_cmd_is_compressible (const mongoc_cmd_t *cmd)
 {
    BSON_ASSERT (cmd);
    BSON_ASSERT (cmd->command_name);
