@@ -1,5 +1,5 @@
 /*
- * Copyright 2018-present MongoDB, Inc.
+ * Copyright 2009-present MongoDB, Inc.
  *
  * Licensed under the Apache License, Version 2.0 (the "License");
  * you may not use this file except in compliance with the License.
@@ -13,9 +13,9 @@
  * See the License for the specific language governing permissions and
  * limitations under the License.
  */
-#include "mongoc/mongoc.h"
-#include "mongoc/mongoc-cursor-private.h"
-#include "mongoc/mongoc-client-private.h"
+#include <mongoc/mongoc.h>
+#include <mongoc/mongoc-cursor-private.h>
+#include <mongoc/mongoc-client-private.h>
 
 /* This cursor is returned by the deprecated functions mongoc_client_command,
  * mongoc_database_command, and mongoc_collection_command. It runs the command
@@ -31,8 +31,7 @@ _prime (mongoc_cursor_t *cursor)
 {
    data_cmd_deprecated_t *data = (data_cmd_deprecated_t *) cursor->impl.data;
    bson_destroy (&data->reply);
-   if (_mongoc_cursor_run_command (
-          cursor, &data->cmd, &cursor->opts, &data->reply, true)) {
+   if (_mongoc_cursor_run_command (cursor, &data->cmd, &cursor->opts, &data->reply, true)) {
       return IN_BATCH;
    } else {
       return DONE;
@@ -52,6 +51,8 @@ _pop_from_batch (mongoc_cursor_t *cursor)
 static mongoc_cursor_state_t
 _get_next_batch (mongoc_cursor_t *cursor)
 {
+   BSON_UNUSED (cursor);
+
    /* there's no next batch to get, return DONE immediately. */
    return DONE;
 }
@@ -61,8 +62,7 @@ static void
 _clone (mongoc_cursor_impl_t *dst, const mongoc_cursor_impl_t *src)
 {
    data_cmd_deprecated_t *data_src = (data_cmd_deprecated_t *) src->data;
-   data_cmd_deprecated_t *data_dst =
-      bson_malloc0 (sizeof (data_cmd_deprecated_t));
+   data_cmd_deprecated_t *data_dst = BSON_ALIGNED_ALLOC0 (data_cmd_deprecated_t);
    bson_init (&data_dst->reply);
    bson_copy_to (&data_src->cmd, &data_dst->cmd);
    dst->data = data_dst;
@@ -85,14 +85,11 @@ _mongoc_cursor_cmd_deprecated_new (mongoc_client_t *client,
                                    const bson_t *cmd,
                                    const mongoc_read_prefs_t *read_prefs)
 {
-   mongoc_cursor_t *cursor =
-      _mongoc_cursor_new_with_opts (client,
-                                    db_and_coll,
-                                    NULL,
-                                    read_prefs /* user prefs */,
-                                    NULL /* default prefs */,
-                                    NULL);
-   data_cmd_deprecated_t *data = bson_malloc0 (sizeof (data_cmd_deprecated_t));
+   BSON_ASSERT_PARAM (client);
+
+   mongoc_cursor_t *cursor = _mongoc_cursor_new_with_opts (
+      client, db_and_coll, NULL, read_prefs /* user prefs */, NULL /* default prefs */, NULL);
+   data_cmd_deprecated_t *data = BSON_ALIGNED_ALLOC0 (data_cmd_deprecated_t);
    _mongoc_cursor_check_and_copy_to (cursor, "command", cmd, &data->cmd);
    bson_init (&data->reply);
    cursor->impl.prime = _prime;
