@@ -1,5 +1,5 @@
 /*
- * Copyright 2013 MongoDB, Inc.
+ * Copyright 2009-present MongoDB, Inc.
  *
  * Licensed under the Apache License, Version 2.0 (the "License");
  * you may not use this file except in compliance with the License.
@@ -14,17 +14,18 @@
  * limitations under the License.
  */
 
-#include "mongoc/mongoc-prelude.h"
+#include <mongoc/mongoc-prelude.h>
 
 #ifndef MONGOC_CURSOR_PRIVATE_H
 #define MONGOC_CURSOR_PRIVATE_H
 
 #include <bson/bson.h>
 
-#include "mongoc/mongoc-client.h"
-#include "mongoc/mongoc-buffer-private.h"
-#include "mongoc/mongoc-rpc-private.h"
-#include "mongoc/mongoc-server-stream-private.h"
+#include <mongoc/mongoc-client.h>
+#include <mongoc/mongoc-buffer-private.h>
+#include <mongoc/mongoc-rpc-private.h>
+#include <mongoc/mongoc-server-stream-private.h>
+#include <mongoc/mongoc-cluster-private.h>
 
 
 BSON_BEGIN_DECLS
@@ -90,8 +91,7 @@ BSON_BEGIN_DECLS
 
 typedef struct _mongoc_cursor_impl_t mongoc_cursor_impl_t;
 typedef enum { UNPRIMED, IN_BATCH, END_OF_BATCH, DONE } mongoc_cursor_state_t;
-typedef mongoc_cursor_state_t (*_mongoc_cursor_impl_transition_t) (
-   mongoc_cursor_t *cursor);
+typedef mongoc_cursor_state_t (*_mongoc_cursor_impl_transition_t) (mongoc_cursor_t *cursor);
 struct _mongoc_cursor_impl_t {
    void (*clone) (mongoc_cursor_impl_t *dst, const mongoc_cursor_impl_t *src);
    void (*destroy) (mongoc_cursor_impl_t *ctx);
@@ -103,7 +103,7 @@ struct _mongoc_cursor_impl_t {
 
 /* pre-3.2 and exhaust cursor responses -- read documents from stream. */
 typedef struct _mongoc_cursor_response_legacy {
-   mongoc_rpc_t rpc;
+   mcd_rpc_message *rpc;
    mongoc_buffer_t buffer;
    bson_reader_t *reader;
 } mongoc_cursor_response_legacy_t;
@@ -120,7 +120,7 @@ struct _mongoc_cursor_t {
    uint32_t client_generation;
 
    uint32_t server_id;
-   bool slave_ok;
+   bool secondary_ok;
 
    mongoc_cursor_state_t state;
    bool in_exhaust;
@@ -131,12 +131,22 @@ struct _mongoc_cursor_t {
    mongoc_read_prefs_t *read_prefs;
    mongoc_write_concern_t *write_concern;
 
+   /** If the cursor was created for an operation that might have overridden the
+    * user's read preferences' read mode, then server selection forced the
+    * cursor to use a read preference mode of 'primary' server. Whether this
+    * force occurred is stored here: */
+   bool must_use_primary;
+
+   /** Whether this cursor corresponds to an aggregate command that contains a
+    * writing-stage */
+   bool is_aggr_with_write_stage;
+
    bool explicit_session;
    mongoc_client_session_t *client_session;
 
    uint32_t count;
 
-   char ns[140];
+   char *ns;
    uint32_t nslen;
    uint32_t dblen;
 
@@ -158,33 +168,21 @@ _mongoc_set_cursor_ns (mongoc_cursor_t *cursor, const char *ns, uint32_t nslen);
 bool
 _mongoc_cursor_get_opt_bool (const mongoc_cursor_t *cursor, const char *option);
 void
-_mongoc_cursor_flags_to_opts (mongoc_query_flags_t qflags,
-                              bson_t *opts,
-                              bool *slave_ok);
+_mongoc_cursor_flags_to_opts (mongoc_query_flags_t qflags, bson_t *opts, bool *secondary_ok);
 bool
-_mongoc_cursor_translate_dollar_query_opts (const bson_t *query,
-                                            bson_t *opts,
-                                            bson_t *unwrapped,
-                                            bson_error_t *error);
+_mongoc_cursor_translate_dollar_query_opts (const bson_t *query, bson_t *opts, bson_t *unwrapped, bson_error_t *error);
 mongoc_server_stream_t *
-_mongoc_cursor_fetch_stream (mongoc_cursor_t *cursor);
+_mongoc_cursor_fetch_stream (mongoc_cursor_t *cursor, const mongoc_ss_log_context_t *log_context);
 void
-_mongoc_cursor_collection (const mongoc_cursor_t *cursor,
-                           const char **collection,
-                           int *collection_len);
+_mongoc_cursor_collection (const mongoc_cursor_t *cursor, const char **collection, int *collection_len);
 bool
-_mongoc_cursor_run_command (mongoc_cursor_t *cursor,
-                            const bson_t *command,
-                            const bson_t *opts,
-                            bson_t *reply,
-                            bool retry_prohibited);
+_mongoc_cursor_run_command (
+   mongoc_cursor_t *cursor, const bson_t *command, const bson_t *opts, bson_t *reply, bool retry_prohibited);
 bool
 _mongoc_cursor_more (mongoc_cursor_t *cursor);
 
 bool
-_mongoc_cursor_set_opt_int64 (mongoc_cursor_t *cursor,
-                              const char *option,
-                              int64_t value);
+_mongoc_cursor_set_opt_int64 (mongoc_cursor_t *cursor, const char *option, int64_t value);
 void
 _mongoc_cursor_monitor_failed (mongoc_cursor_t *cursor,
                                int64_t duration,
@@ -196,17 +194,15 @@ _mongoc_cursor_monitor_command (mongoc_cursor_t *cursor,
                                 const bson_t *cmd,
                                 const char *cmd_name);
 void
-_mongoc_cursor_prepare_find_command (mongoc_cursor_t *cursor,
-                                     const bson_t *filter,
-                                     bson_t *command);
+_mongoc_cursor_prepare_find_command (mongoc_cursor_t *cursor, const bson_t *filter, bson_t *command);
 const bson_t *
 _mongoc_cursor_initial_query (mongoc_cursor_t *cursor);
 const bson_t *
 _mongoc_cursor_get_more (mongoc_cursor_t *cursor);
 bool
-_mongoc_cursor_opts_to_flags (mongoc_cursor_t *cursor,
-                              mongoc_server_stream_t *stream,
-                              mongoc_query_flags_t *flags /* OUT */);
+_mongoc_cursor_opts_to_flags (mongoc_cursor_t *cursor, mongoc_server_stream_t *stream, int32_t *flags /* OUT */);
+bool
+_mongoc_cursor_use_op_msg (const mongoc_cursor_t *cursor, int32_t wire_version);
 void
 _mongoc_cursor_monitor_succeeded (mongoc_cursor_t *cursor,
                                   mongoc_cursor_response_legacy_t *response,
@@ -223,34 +219,24 @@ _mongoc_cursor_response_refresh (mongoc_cursor_t *cursor,
                                  const bson_t *opts,
                                  mongoc_cursor_response_t *response);
 bool
-_mongoc_cursor_start_reading_response (mongoc_cursor_t *cursor,
-                                       mongoc_cursor_response_t *response);
+_mongoc_cursor_start_reading_response (mongoc_cursor_t *cursor, mongoc_cursor_response_t *response);
 void
-_mongoc_cursor_response_read (mongoc_cursor_t *cursor,
-                              mongoc_cursor_response_t *response,
-                              const bson_t **bson);
+_mongoc_cursor_response_read (mongoc_cursor_t *cursor, mongoc_cursor_response_t *response, const bson_t **bson);
 void
-_mongoc_cursor_prepare_getmore_command (mongoc_cursor_t *cursor,
-                                        bson_t *command);
+_mongoc_cursor_prepare_getmore_command (mongoc_cursor_t *cursor, bson_t *command);
 void
 _mongoc_cursor_set_empty (mongoc_cursor_t *cursor);
 bool
-_mongoc_cursor_check_and_copy_to (mongoc_cursor_t *cursor,
-                                  const char *err_prefix,
-                                  const bson_t *src,
-                                  bson_t *dst);
+_mongoc_cursor_check_and_copy_to (mongoc_cursor_t *cursor, const char *err_prefix, const bson_t *src, bson_t *dst);
 void
 _mongoc_cursor_prime (mongoc_cursor_t *cursor);
 /* legacy functions defined in mongoc-cursor-legacy.c */
 bool
 _mongoc_cursor_next (mongoc_cursor_t *cursor, const bson_t **bson);
 bool
-_mongoc_cursor_op_query_find (mongoc_cursor_t *cursor,
-                              bson_t *filter,
-                              mongoc_cursor_response_legacy_t *response);
+_mongoc_cursor_op_query_find (mongoc_cursor_t *cursor, bson_t *filter, mongoc_cursor_response_legacy_t *response);
 void
-_mongoc_cursor_op_getmore (mongoc_cursor_t *cursor,
-                           mongoc_cursor_response_legacy_t *response);
+_mongoc_cursor_op_getmore (mongoc_cursor_t *cursor, mongoc_cursor_response_legacy_t *response);
 mongoc_cursor_t *
 _mongoc_cursor_new_with_opts (mongoc_client_t *client,
                               const char *db_and_collection,
@@ -261,8 +247,7 @@ _mongoc_cursor_new_with_opts (mongoc_client_t *client,
 void
 _mongoc_cursor_response_legacy_init (mongoc_cursor_response_legacy_t *response);
 void
-_mongoc_cursor_response_legacy_destroy (
-   mongoc_cursor_response_legacy_t *response);
+_mongoc_cursor_response_legacy_destroy (mongoc_cursor_response_legacy_t *response);
 /* cursor constructors. */
 mongoc_cursor_t *
 _mongoc_cursor_find_new (mongoc_client_t *client,
@@ -283,10 +268,7 @@ _mongoc_cursor_cmd_new (mongoc_client_t *client,
                         const mongoc_read_concern_t *read_concern);
 
 mongoc_cursor_t *
-_mongoc_cursor_cmd_new_from_reply (mongoc_client_t *client,
-                                   const bson_t *cmd,
-                                   const bson_t *opts,
-                                   bson_t *reply);
+_mongoc_cursor_cmd_new_from_reply (mongoc_client_t *client, const bson_t *cmd, const bson_t *opts, bson_t *reply);
 
 mongoc_cursor_t *
 _mongoc_cursor_cmd_deprecated_new (mongoc_client_t *client,
@@ -295,27 +277,20 @@ _mongoc_cursor_cmd_deprecated_new (mongoc_client_t *client,
                                    const mongoc_read_prefs_t *read_prefs);
 
 mongoc_cursor_t *
-_mongoc_cursor_array_new (mongoc_client_t *client,
-                          const char *db_and_coll,
-                          const bson_t *cmd,
-                          const bson_t *opts,
-                          const char *field_name);
+_mongoc_cursor_array_new (
+   mongoc_client_t *client, const char *db_and_coll, const bson_t *cmd, const bson_t *opts, const char *field_name);
 
 mongoc_cursor_t *
-_mongoc_cursor_change_stream_new (mongoc_client_t *client,
-                                  bson_t *reply,
-                                  const bson_t *opts);
+_mongoc_cursor_change_stream_new (mongoc_client_t *client, bson_t *reply, const bson_t *opts);
 
 bool
 _mongoc_cursor_change_stream_end_of_batch (mongoc_cursor_t *cursor);
 
 const bson_t *
-_mongoc_cursor_change_stream_get_post_batch_resume_token (
-   mongoc_cursor_t *cursor);
+_mongoc_cursor_change_stream_get_post_batch_resume_token (mongoc_cursor_t *cursor);
 
 bool
-_mongoc_cursor_change_stream_has_post_batch_resume_token (
-   mongoc_cursor_t *cursor);
+_mongoc_cursor_change_stream_has_post_batch_resume_token (mongoc_cursor_t *cursor);
 
 const bson_t *
 _mongoc_cursor_change_stream_get_reply (mongoc_cursor_t *cursor);
