@@ -1,5 +1,5 @@
 /*
- * Copyright 2014 MongoDB, Inc.
+ * Copyright 2009-present MongoDB, Inc.
  *
  * Licensed under the Apache License, Version 2.0 (the "License");
  * you may not use this file except in compliance with the License.
@@ -15,9 +15,11 @@
  */
 
 
-#include "mongoc/mongoc-log.h"
-#include "mongoc/mongoc-matcher-op-private.h"
-#include "mongoc/mongoc-util-private.h"
+#include <mongoc/mongoc-log.h>
+#include <mongoc/mongoc-matcher-op-private.h>
+#include <mongoc/mongoc-util-private.h>
+
+#include <inttypes.h>
 
 /*
  *--------------------------------------------------------------------------
@@ -44,7 +46,7 @@ _mongoc_matcher_op_exists_new (const char *path, /* IN */
 
    BSON_ASSERT (path);
 
-   op = (mongoc_matcher_op_t *) bson_malloc0 (sizeof *op);
+   op = BSON_ALIGNED_ALLOC0 (mongoc_matcher_op_t);
    op->exists.base.opcode = MONGOC_MATCHER_OPCODE_EXISTS;
    op->exists.path = bson_strdup (path);
    op->exists.exists = exists;
@@ -79,7 +81,7 @@ _mongoc_matcher_op_type_new (const char *path, /* IN */
    BSON_ASSERT (path);
    BSON_ASSERT (type);
 
-   op = (mongoc_matcher_op_t *) bson_malloc0 (sizeof *op);
+   op = BSON_ALIGNED_ALLOC0 (mongoc_matcher_op_t);
    op->type.base.opcode = MONGOC_MATCHER_OPCODE_TYPE;
    op->type.path = bson_strdup (path);
    op->type.type = type;
@@ -117,10 +119,9 @@ _mongoc_matcher_op_logical_new (mongoc_matcher_opcode_t opcode, /* IN */
    mongoc_matcher_op_t *op;
 
    BSON_ASSERT (left);
-   BSON_ASSERT ((opcode >= MONGOC_MATCHER_OPCODE_OR) &&
-                (opcode <= MONGOC_MATCHER_OPCODE_NOR));
+   BSON_ASSERT ((opcode >= MONGOC_MATCHER_OPCODE_OR) && (opcode <= MONGOC_MATCHER_OPCODE_NOR));
 
-   op = (mongoc_matcher_op_t *) bson_malloc0 (sizeof *op);
+   op = BSON_ALIGNED_ALLOC0 (mongoc_matcher_op_t);
    op->logical.base.opcode = opcode;
    op->logical.left = left;
    op->logical.right = right;
@@ -165,7 +166,7 @@ _mongoc_matcher_op_compare_new (mongoc_matcher_opcode_t opcode, /* IN */
    BSON_ASSERT (path);
    BSON_ASSERT (iter);
 
-   op = (mongoc_matcher_op_t *) bson_malloc0 (sizeof *op);
+   op = BSON_ALIGNED_ALLOC0 (mongoc_matcher_op_t);
    op->compare.base.opcode = opcode;
    op->compare.path = bson_strdup (path);
    memcpy (&op->compare.iter, iter, sizeof *iter);
@@ -200,7 +201,7 @@ _mongoc_matcher_op_not_new (const char *path,           /* IN */
    BSON_ASSERT (path);
    BSON_ASSERT (child);
 
-   op = (mongoc_matcher_op_t *) bson_malloc0 (sizeof *op);
+   op = BSON_ALIGNED_ALLOC0 (mongoc_matcher_op_t);
    op->not_.base.opcode = MONGOC_MATCHER_OPCODE_NOT;
    op->not_.path = bson_strdup (path);
    op->not_.child = child;
@@ -298,8 +299,7 @@ _mongoc_matcher_op_exists_match (mongoc_matcher_op_exists_t *exists, /* IN */
    BSON_ASSERT (exists);
    BSON_ASSERT (bson);
 
-   found = (bson_iter_init (&iter, bson) &&
-            bson_iter_find_descendant (&iter, exists->path, &desc));
+   found = (bson_iter_init (&iter, bson) && bson_iter_find_descendant (&iter, exists->path, &desc));
 
    return (found == exists->exists);
 }
@@ -332,8 +332,7 @@ _mongoc_matcher_op_type_match (mongoc_matcher_op_type_t *type, /* IN */
    BSON_ASSERT (type);
    BSON_ASSERT (bson);
 
-   if (bson_iter_init (&iter, bson) &&
-       bson_iter_find_descendant (&iter, type->path, &desc)) {
+   if (bson_iter_init (&iter, bson) && bson_iter_find_descendant (&iter, type->path, &desc)) {
       return (bson_iter_type (&iter) == type->type);
    }
 
@@ -371,8 +370,7 @@ _mongoc_matcher_op_not_match (mongoc_matcher_op_not_t *not_, /* IN */
 
 
 #define _TYPE_CODE(l, r) ((((int) (l)) << 8) | ((int) (r)))
-#define _NATIVE_COMPARE(op, t1, t2) \
-   (bson_iter##t2 (iter) op bson_iter##t1 (compare_iter))
+#define _NATIVE_COMPARE(op, t1, t2) (bson_iter##t2 (iter) op bson_iter##t1 (compare_iter))
 #define _EQ_COMPARE(t1, t2) _NATIVE_COMPARE (==, t1, t2)
 #define _NE_COMPARE(t1, t2) _NATIVE_COMPARE (!=, t1, t2)
 #define _GT_COMPARE(t1, t2) _NATIVE_COMPARE (>, t1, t2)
@@ -604,9 +602,8 @@ _mongoc_matcher_op_gt_match (mongoc_matcher_op_compare_t *compare, /* IN */
       return _GT_COMPARE (_int64, _int64);
 
    default:
-      MONGOC_WARNING ("Implement for (Type(%d) > Type(%d))",
-                      bson_iter_type (compare_iter),
-                      bson_iter_type (iter));
+      MONGOC_WARNING (
+         "Implement for (Type(%d) > Type(%d))", (int) bson_iter_type (compare_iter), (int) bson_iter_type (iter));
       break;
    }
 
@@ -675,9 +672,8 @@ _mongoc_matcher_op_gte_match (mongoc_matcher_op_compare_t *compare, /* IN */
       return _GTE_COMPARE (_int64, _int64);
 
    default:
-      MONGOC_WARNING ("Implement for (Type(%d) >= Type(%d))",
-                      bson_iter_type (compare_iter),
-                      bson_iter_type (iter));
+      MONGOC_WARNING (
+         "Implement for (Type(%d) >= Type(%d))", (int) bson_iter_type (compare_iter), (int) bson_iter_type (iter));
       break;
    }
 
@@ -710,8 +706,7 @@ _mongoc_matcher_op_in_match (mongoc_matcher_op_compare_t *compare, /* IN */
    op.base.opcode = MONGOC_MATCHER_OPCODE_EQ;
    op.path = compare->path;
 
-   if (!BSON_ITER_HOLDS_ARRAY (&compare->iter) ||
-       !bson_iter_recurse (&compare->iter, &op.iter)) {
+   if (!BSON_ITER_HOLDS_ARRAY (&compare->iter) || !bson_iter_recurse (&compare->iter, &op.iter)) {
       return false;
    }
 
@@ -786,9 +781,8 @@ _mongoc_matcher_op_lt_match (mongoc_matcher_op_compare_t *compare, /* IN */
       return _LT_COMPARE (_int64, _int64);
 
    default:
-      MONGOC_WARNING ("Implement for (Type(%d) < Type(%d))",
-                      bson_iter_type (compare_iter),
-                      bson_iter_type (iter));
+      MONGOC_WARNING (
+         "Implement for (Type(%d) < Type(%d))", (int) bson_iter_type (compare_iter), (int) bson_iter_type (iter));
       break;
    }
 
@@ -857,9 +851,8 @@ _mongoc_matcher_op_lte_match (mongoc_matcher_op_compare_t *compare, /* IN */
       return _LTE_COMPARE (_int64, _int64);
 
    default:
-      MONGOC_WARNING ("Implement for (Type(%d) <= Type(%d))",
-                      bson_iter_type (compare_iter),
-                      bson_iter_type (iter));
+      MONGOC_WARNING (
+         "Implement for (Type(%d) <= Type(%d))", (int) bson_iter_type (compare_iter), (int) bson_iter_type (iter));
       break;
    }
 
@@ -944,8 +937,7 @@ _mongoc_matcher_op_compare_match (mongoc_matcher_op_compare_t *compare, /* IN */
    BSON_ASSERT (bson);
 
    if (strchr (compare->path, '.')) {
-      if (!bson_iter_init (&tmp, bson) ||
-          !bson_iter_find_descendant (&tmp, compare->path, &iter)) {
+      if (!bson_iter_init (&tmp, bson) || !bson_iter_find_descendant (&tmp, compare->path, &iter)) {
          return false;
       }
    } else if (!bson_iter_init_find (&iter, bson, compare->path)) {
@@ -1004,14 +996,11 @@ _mongoc_matcher_op_logical_match (mongoc_matcher_op_logical_t *logical, /* IN */
 
    switch ((int) logical->base.opcode) {
    case MONGOC_MATCHER_OPCODE_OR:
-      return (_mongoc_matcher_op_match (logical->left, bson) ||
-              _mongoc_matcher_op_match (logical->right, bson));
+      return (_mongoc_matcher_op_match (logical->left, bson) || _mongoc_matcher_op_match (logical->right, bson));
    case MONGOC_MATCHER_OPCODE_AND:
-      return (_mongoc_matcher_op_match (logical->left, bson) &&
-              _mongoc_matcher_op_match (logical->right, bson));
+      return (_mongoc_matcher_op_match (logical->left, bson) && _mongoc_matcher_op_match (logical->right, bson));
    case MONGOC_MATCHER_OPCODE_NOR:
-      return !(_mongoc_matcher_op_match (logical->left, bson) ||
-               _mongoc_matcher_op_match (logical->right, bson));
+      return !(_mongoc_matcher_op_match (logical->left, bson) || _mongoc_matcher_op_match (logical->right, bson));
    default:
       BSON_ASSERT (false);
       break;
@@ -1157,16 +1146,19 @@ _mongoc_matcher_op_to_bson (mongoc_matcher_op_t *op, /* IN */
          BSON_ASSERT (false);
          str = NULL;
       }
-      bson_append_array_begin (bson, str, -1, &child);
-      bson_append_document_begin (&child, "0", 1, &child2);
-      _mongoc_matcher_op_to_bson (op->logical.left, &child2);
-      bson_append_document_end (&child, &child2);
-      if (op->logical.right) {
-         bson_append_document_begin (&child, "1", 1, &child2);
-         _mongoc_matcher_op_to_bson (op->logical.right, &child2);
-         bson_append_document_end (&child, &child2);
+      {
+         bson_array_builder_t *bab;
+         bson_append_array_builder_begin (bson, str, -1, &bab);
+         bson_array_builder_append_document_begin (bab, &child2);
+         _mongoc_matcher_op_to_bson (op->logical.left, &child2);
+         bson_array_builder_append_document_end (bab, &child2);
+         if (op->logical.right) {
+            bson_array_builder_append_document_begin (bab, &child2);
+            _mongoc_matcher_op_to_bson (op->logical.right, &child2);
+            bson_array_builder_append_document_end (bab, &child2);
+         }
+         bson_append_array_builder_end (bson, bab);
       }
-      bson_append_array_end (bson, &child);
       break;
    case MONGOC_MATCHER_OPCODE_NOT:
       bson_append_document_begin (bson, op->not_.path, -1, &child);
