@@ -1,5 +1,5 @@
 /*
- * Copyright 2013 MongoDB, Inc.
+ * Copyright 2009-present MongoDB, Inc.
  *
  * Licensed under the Apache License, Version 2.0 (the "License");
  * you may not use this file except in compliance with the License.
@@ -17,9 +17,9 @@
 #ifndef MONGOC_RPC_PRIVATE_H
 #define MONGOC_RPC_PRIVATE_H
 
-#include "mongoc-prelude.h"
+#include <mongoc/mongoc-prelude.h>
 
-#include "mcd-rpc.h"
+#include <mongoc/mcd-rpc.h>
 
 #include <bson/bson.h>
 
