@@ -16,17 +16,20 @@
 
 #include <bson/bson.h>
 
-#include "mongoc-client-private.h"
-#include "mongoc-client-session-private.h"
-#include "mongoc-client-side-encryption-private.h"
-#include "mongoc-error.h"
-#include "mongoc-error-private.h"
-#include "mongoc-trace-private.h"
-#include "mongoc-write-command-private.h"
-#include "mongoc-write-concern-private.h"
-#include "mongoc-util-private.h"
-#include "mongoc-opts-private.h"
+#include <mongoc/mongoc-client-private.h>
+#include <mongoc/mongoc-client-session-private.h>
+#include <mongoc/mongoc-client-side-encryption-private.h>
+#include <mongoc/mongoc-error.h>
+#include <mongoc/mongoc-error-private.h>
+#include <mongoc/mongoc-trace-private.h>
+#include <mongoc/mongoc-write-command-private.h>
+#include <mongoc/mongoc-write-concern-private.h>
+#include <mongoc/mongoc-util-private.h>
+#include <mongoc/mongoc-opts-private.h>
+#include <common-string-private.h>
+#include <common-cmp-private.h>
 
+#include <inttypes.h>
 
 /* indexed by MONGOC_WRITE_COMMAND_DELETE, INSERT, UPDATE */
 static const char *gCommandNames[] = {"delete", "insert", "update"};
@@ -334,6 +337,15 @@ _mongoc_write_command_init_update_idl (mongoc_write_command_t *command,
 }
 
 
+const char *
+_mongoc_write_command_get_name (const mongoc_write_command_t *command)
+{
+   BSON_ASSERT_PARAM (command);
+   BSON_ASSERT (command->type >= 0 && command->type < (int) (sizeof gCommandNames / sizeof gCommandNames[0]));
+   return gCommandNames[command->type];
+}
+
+
 /* takes initialized bson_t *doc and begins formatting a write command */
 void
 _mongoc_write_command_init (bson_t *doc, mongoc_write_command_t *command, const char *collection)
@@ -344,7 +356,7 @@ _mongoc_write_command_init (bson_t *doc, mongoc_write_command_t *command, const
       EXIT;
    }
 
-   BSON_APPEND_UTF8 (doc, gCommandNames[command->type], collection);
+   BSON_APPEND_UTF8 (doc, _mongoc_write_command_get_name (command), collection);
    BSON_APPEND_BOOL (doc, "ordered", command->flags.ordered);
 
    if (command->flags.bypass_document_validation) {
@@ -381,8 +393,8 @@ _mongoc_write_command_too_large_error (bson_error_t *error, int32_t idx, int32_t
    bson_set_error (error,
                    MONGOC_ERROR_BSON,
                    MONGOC_ERROR_BSON_INVALID,
-                   "Document %u is too large for the cluster. "
-                   "Document is %u bytes, max is %d.",
+                   "Document %" PRId32 " is too large for the cluster. "
+                   "Document is %" PRId32 " bytes, max is %" PRId32 ".",
                    idx,
                    len,
                    max_bson_size);
@@ -396,8 +408,11 @@ _empty_error (mongoc_write_command_t *command, bson_error_t *error)
                                     MONGOC_ERROR_COLLECTION_INSERT_FAILED,
                                     MONGOC_ERROR_COLLECTION_UPDATE_FAILED};
 
-   bson_set_error (
-      error, MONGOC_ERROR_COLLECTION, codes[command->type], "Cannot do an empty %s", gCommandNames[command->type]);
+   bson_set_error (error,
+                   MONGOC_ERROR_COLLECTION,
+                   codes[command->type],
+                   "Cannot do an empty %s",
+                   _mongoc_write_command_get_name (command));
 }
 
 
@@ -688,7 +703,7 @@ _mongoc_write_opmsg (mongoc_write_command_t *command,
       ulen = BSON_UINT32_FROM_LE (ulen);
 
       // Although messageLength is an int32, it should never be negative.
-      BSON_ASSERT (bson_in_range_unsigned (int32_t, ulen));
+      BSON_ASSERT (mcommon_in_range_unsigned (int32_t, ulen));
       const int32_t slen = (int32_t) ulen;
 
       if (slen > max_bson_obj_size + BSON_OBJECT_ALLOWANCE) {
@@ -697,7 +712,7 @@ _mongoc_write_opmsg (mongoc_write_command_t *command,
          result->failed = true;
          break;
 
-      } else if (bson_cmp_less_equal_us (payload_batch_size + opmsg_overhead + ulen, max_msg_size) ||
+      } else if (mcommon_cmp_less_equal_us (payload_batch_size + opmsg_overhead + ulen, max_msg_size) ||
                  document_count == 0) {
          /* The current batch is still under max batch size in bytes */
          payload_batch_size += ulen;
@@ -986,15 +1001,16 @@ _set_error_from_response (bson_t *bson_array,
 {
    bson_iter_t array_iter;
    bson_iter_t doc_iter;
-   bson_string_t *compound_err;
    const char *errmsg = NULL;
    int32_t code = 0;
    uint32_t n_keys, i;
 
-   compound_err = bson_string_new (NULL);
+   mcommon_string_append_t compound_err;
+   mcommon_string_new_as_fixed_capacity_append (&compound_err, sizeof error->message - 1u);
+
    n_keys = bson_count_keys (bson_array);
    if (n_keys > 1) {
-      bson_string_append_printf (compound_err, "Multiple %s errors: ", error_type);
+      mcommon_string_append_printf (&compound_err, "Multiple %s errors: ", error_type);
    }
 
    if (!bson_empty0 (bson_array) && bson_iter_init (&array_iter, bson_array)) {
@@ -1013,13 +1029,13 @@ _set_error_from_response (bson_t *bson_array,
 
                   /* build message like 'Multiple write errors: "foo", "bar"' */
                   if (n_keys > 1) {
-                     bson_string_append_printf (compound_err, "\"%s\"", errmsg);
+                     mcommon_string_append_printf (&compound_err, "\"%s\"", errmsg);
                      if (i < n_keys - 1) {
-                        bson_string_append (compound_err, ", ");
+                        mcommon_string_append (&compound_err, ", ");
                      }
                   } else {
                      /* single error message */
-                     bson_string_append (compound_err, errmsg);
+                     mcommon_string_append (&compound_err, errmsg);
                   }
                }
             }
@@ -1028,12 +1044,12 @@ _set_error_from_response (bson_t *bson_array,
          }
       }
 
-      if (code && compound_err->len) {
-         bson_set_error (error, domain, (uint32_t) code, "%s", compound_err->str);
+      if (code && !mcommon_string_from_append_is_empty (&compound_err)) {
+         bson_set_error (error, domain, (uint32_t) code, "%s", mcommon_str_from_append (&compound_err));
       }
    }
 
-   bson_string_free (compound_err, true);
+   mcommon_string_from_append_destroy (&compound_err);
 }
 
 
